@@ -1,5 +1,5 @@
 #coding = utf-8
-__version__ = '0.3.9'
+__version__ = '0.3.10'
 
 import random
 from termcolor import colored, cprint
@@ -22,7 +22,7 @@ def pathToSave()->str:
 
 
 
-from datas import variables, loading, setGrid, getPlayers, notDone, isWinner, setIcon
+from Morpion.datas import variables, loading, setGrid, getPlayers, notDone, isWinner, setIcon
 vars = variables()
 colors = vars.colors
 cases = vars.scheme
